@@ -17,7 +17,7 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
-# 请求头中的 Uin 无效
+# 请求头中的 Uin 无效。
 AUTHFAILURE_INVALIDHEADERUIN = 'AuthFailure.InvalidHeaderUin'
 
 # 该地域尚未开放，请选择其他地域。
@@ -26,6 +26,9 @@ AUTHFAILURE_INVALIDREGION = 'AuthFailure.InvalidRegion'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 账户余额不足。
+FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
+
 # 创建镜像失败。
 FAILEDOPERATION_CREATEBLUEPRINTFAILED = 'FailedOperation.CreateBlueprintFailed'
 
@@ -41,13 +44,16 @@ FAILEDOPERATION_CREATEKEYPAIRFAILED = 'FailedOperation.CreateKeyPairFailed'
 # 对密钥对的删除操作失败。
 FAILEDOPERATION_DELETEKEYPAIRFAILED = 'FailedOperation.DeleteKeyPairFailed'
 
+# 查询镜像配额失败。
+FAILEDOPERATION_DESCRIBEBLUEPRINTQUOTAFAILED = 'FailedOperation.DescribeBlueprintQuotaFailed'
+
 # 查询镜像失败，请稍后再试。
 FAILEDOPERATION_DESCRIBEBLUEPRINTSFAILED = 'FailedOperation.DescribeBlueprintsFailed'
 
-# 查询套餐折扣失败
+# 查询套餐折扣失败。
 FAILEDOPERATION_DESCRIBEBUNDLEDISCOUNTFAILED = 'FailedOperation.DescribeBundleDiscountFailed'
 
-# 查询套餐失败
+# 查询套餐失败。
 FAILEDOPERATION_DESCRIBEBUNDLESFAILED = 'FailedOperation.DescribeBundlesFailed'
 
 # 查询云硬盘是否可以退还操作失败。
@@ -101,9 +107,12 @@ FAILEDOPERATION_MODIFYINSTANCESBUNDLEFAILED = 'FailedOperation.ModifyInstancesBu
 # 变更资源属性失败，请稍后重新操作。
 FAILEDOPERATION_MODIFYRESOURCESATTRIBUTEFAILED = 'FailedOperation.ModifyResourcesAttributeFailed'
 
-# 修改资源自动续费失败
+# 修改资源自动续费失败。
 FAILEDOPERATION_MODIFYRESOURCESRENEWFLAGFAILED = 'FailedOperation.ModifyResourcesRenewFlagFailed'
 
+# 购买数量超过最大限制。
+FAILEDOPERATION_NUMLIMITERROR = 'FailedOperation.NumLimitError'
+
 # 续费资源失败。
 FAILEDOPERATION_RENEWRESOURCESFAILED = 'FailedOperation.RenewResourcesFailed'
 
@@ -134,6 +143,9 @@ FAILEDOPERATION_UNABLETOCREATEBLUEPRINT = 'FailedOperation.UnableToCreateBluepri
 # 无法创建实例。
 FAILEDOPERATION_UNABLETOCREATEINSTANCES = 'FailedOperation.UnableToCreateInstances'
 
+# 当前镜像状态无法进行跨地域同步。
+FAILEDOPERATION_UNABLETOSYNCBLUEPRINT = 'FailedOperation.UnableToSyncBlueprint'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -188,6 +200,12 @@ INVALIDPARAMETER_BUNDLEIDNOTFOUND = 'InvalidParameter.BundleIdNotFound'
 # 参数冲突。
 INVALIDPARAMETER_CONFLICT = 'InvalidParameter.Conflict'
 
+# 参数冲突。
+INVALIDPARAMETER_CONFLICTPARAMETER = 'InvalidParameter.ConflictParameter'
+
+# 创建游戏专区实例不支持该参数。
+INVALIDPARAMETER_CREATINGGAMEPORTALINSTANCENOTSUPPORTPARAMETER = 'InvalidParameter.CreatingGamePortalInstanceNotSupportParameter'
+
 # 参数非法，Filter 参数中的 Values 取值数量超过允许的最大数量。
 INVALIDPARAMETER_FILTERVALUELIMITEXCEEDED = 'InvalidParameter.FilterValueLimitExceeded'
 
@@ -269,6 +287,9 @@ INVALIDPARAMETERVALUE_CCNIDMALFORMED = 'InvalidParameterValue.CcnIdMalformed'
 # 客户令牌长度超出限制。
 INVALIDPARAMETERVALUE_CLIENTTOKENTOOLONG = 'InvalidParameterValue.ClientTokenTooLong'
 
+# 目的地域与源地域相同。
+INVALIDPARAMETERVALUE_DESTINATIONREGIONSAMEASSOURCEREGION = 'InvalidParameterValue.DestinationRegionSameAsSourceRegion'
+
 # 参数值非法，云硬盘备份点 ID 格式非法。
 INVALIDPARAMETERVALUE_DISKBACKUPIDMALFORMED = 'InvalidParameterValue.DiskBackupIdMalformed'
 
@@ -296,7 +317,7 @@ INVALIDPARAMETERVALUE_DUPLICATEPARAMETERVALUE = 'InvalidParameterValue.Duplicate
 # 参数值非法，不允许包含重复的值。
 INVALIDPARAMETERVALUE_DUPLICATED = 'InvalidParameterValue.Duplicated'
 
-# 防火墙模板规则已存在
+# 防火墙模板规则已存在。
 INVALIDPARAMETERVALUE_DUPLICATEDFIREWALLTEMPLATERULE = 'InvalidParameterValue.DuplicatedFirewallTemplateRule'
 
 # 列值不正确。
@@ -347,9 +368,6 @@ INVALIDPARAMETERVALUE_INVALIDDISKSIZE = 'InvalidParameterValue.InvalidDiskSize'
 # 云硬盘类型非法。
 INVALIDPARAMETERVALUE_INVALIDDISKTYPE = 'InvalidParameterValue.InvalidDiskType'
 
-# 设置是否使用默认密钥对登录的值不正确。
-INVALIDPARAMETERVALUE_INVALIDINSTANCELOGINKEYPAIRPERMITLOGIN = 'InvalidParameterValue.InvalidInstanceLoginKeyPairPermitLogin'
-
 # 参数值非法，IP 地址格式非法。
 INVALIDPARAMETERVALUE_INVALIDIPFORMAT = 'InvalidParameterValue.InvalidIpFormat'
 
@@ -398,6 +416,9 @@ INVALIDPARAMETERVALUE_NEGATIVE = 'InvalidParameterValue.Negative'
 # 不允许改变平台类型。
 INVALIDPARAMETERVALUE_NOTALLOWTOCHANGEPLATFORMTYPE = 'InvalidParameterValue.NotAllowToChangePlatformType'
 
+# 不支持跨境同步镜像。
+INVALIDPARAMETERVALUE_NOTSUPPORTCROSSBORDERSYNCBLUEPRINT = 'InvalidParameterValue.NotSupportCrossBorderSyncBlueprint'
+
 # 实例套餐的套餐类型不支持表更至新套餐。
 INVALIDPARAMETERVALUE_NOTSUPPORTMODIFYINSTANCEBUNDLETYPE = 'InvalidParameterValue.NotSupportModifyInstanceBundleType'
 
@@ -437,6 +458,9 @@ INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 # 参数值非法，小于有效值。
 INVALIDPARAMETERVALUE_TOOSMALL = 'InvalidParameterValue.TooSmall'
 
+# 地域不可用。
+INVALIDPARAMETERVALUE_UNAVAILABLEREGION = 'InvalidParameterValue.UnavailableRegion'
+
 # 非法的可用区。
 INVALIDPARAMETERVALUE_ZONEINVALID = 'InvalidParameterValue.ZoneInvalid'
 
@@ -458,7 +482,7 @@ LIMITEXCEEDED_DISKQUOTALIMITEXCEEDED = 'LimitExceeded.DiskQuotaLimitExceeded'
 # 超过防火墙规则配额。
 LIMITEXCEEDED_FIREWALLRULESLIMITEXCEEDED = 'LimitExceeded.FirewallRulesLimitExceeded'
 
-# 防火墙模板规则超出配额
+# 防火墙模板规则超出配额。
 LIMITEXCEEDED_FIREWALLTEMPLATERULEQUOTALIMITEXCEEDED = 'LimitExceeded.FirewallTemplateRuleQuotaLimitExceeded'
 
 # 超过实例配额。
@@ -476,6 +500,9 @@ LIMITEXCEEDED_SHAREBLUEPRINTACROSSACCOUNTQUOTALIMITEXCEEDED = 'LimitExceeded.Sha
 # 超过快照配额。
 LIMITEXCEEDED_SNAPSHOTQUOTALIMITEXCEEDED = 'LimitExceeded.SnapshotQuotaLimitExceeded'
 
+# 超过同步镜像目的地域镜像配额。
+LIMITEXCEEDED_SYNCBLUEPRINTQUOTALIMITEXCEEDED = 'LimitExceeded.SyncBlueprintQuotaLimitExceeded'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -569,10 +596,10 @@ RESOURCENOTFOUND_FIREWALLNOTFOUND = 'ResourceNotFound.FirewallNotFound'
 # 防火墙规则不存在。
 RESOURCENOTFOUND_FIREWALLRULESNOTFOUND = 'ResourceNotFound.FirewallRulesNotFound'
 
-# 防火墙模板不存在
+# 防火墙模板不存在。
 RESOURCENOTFOUND_FIREWALLTEMPLATENOTFOUND = 'ResourceNotFound.FirewallTemplateNotFound'
 
-# 防火墙模板规则不存在
+# 防火墙模板规则不存在。
 RESOURCENOTFOUND_FIREWALLTEMPLATERULENOTFOUND = 'ResourceNotFound.FirewallTemplateRuleNotFound'
 
 # 实例不存在挂载的数据盘。
@@ -617,7 +644,7 @@ RESOURCEUNAVAILABLE_BLUEPRINTUNAVAILABLE = 'ResourceUnavailable.BlueprintUnavail
 # 套餐不可用。
 RESOURCEUNAVAILABLE_BUNDLEUNAVAILABLE = 'ResourceUnavailable.BundleUnavailable'
 
-# 不能应用该防火墙模板
+# 不能应用该防火墙模板。
 RESOURCEUNAVAILABLE_CANNOTAPPLYEMPTYFIREWALLTEMPLATE = 'ResourceUnavailable.CannotApplyEmptyFirewallTemplate'
 
 # Docker资源不可用。
@@ -647,6 +674,9 @@ RESOURCESSOLDOUT_ZONESHASNOBUNDLECONFIGS = 'ResourcesSoldOut.ZonesHasNoBundleCon
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 因账号安全升级，购买云资源需完善您的实名信息。
+UNAUTHORIZEDOPERATION_CERTIFICATIONNEEDUPGRADE = 'UnauthorizedOperation.CertificationNeedUpgrade'
+
 # 无效 Token。
 UNAUTHORIZEDOPERATION_INVALIDTOKEN = 'UnauthorizedOperation.InvalidToken'
 
@@ -659,6 +689,9 @@ UNAUTHORIZEDOPERATION_MFANOTFOUND = 'UnauthorizedOperation.MFANotFound'
 # 无权限。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
+# 账号没有实名认证，支付失败。
+UNAUTHORIZEDOPERATION_NOTCERTIFICATION = 'UnauthorizedOperation.NotCertification'
+
 # 无权限进行此操作，请求中token不合法。
 UNAUTHORIZEDOPERATION_TOKENINVALID = 'UnauthorizedOperation.TokenInvalid'
 
@@ -764,9 +797,6 @@ UNSUPPORTEDOPERATION_OPERATIONNOTSUPPORTAUTOGENERATEPASSWORD = 'UnsupportedOpera
 # 国际站不支持该操作。
 UNSUPPORTEDOPERATION_OPERATIONNOTSUPPORTEDININTLSITE = 'UnsupportedOperation.OperationNotSupportedInIntlSite'
 
-# 此接口已下线。
-UNSUPPORTEDOPERATION_OPERATIONOFFLINE = 'UnsupportedOperation.OperationOffline'
-
 # 计费资源中心删除资源失败。
 UNSUPPORTEDOPERATION_POSTDESTROYRESOURCEFAILED = 'UnsupportedOperation.PostDestroyResourceFailed'
 
